Index: trunk/psLib/src/astro/psTime.h
===================================================================
--- trunk/psLib/src/astro/psTime.h	(revision 22680)
+++ trunk/psLib/src/astro/psTime.h	(revision 22682)
@@ -135,9 +135,9 @@
 /** Convert psTime to UTC, TAI, UT1, or TT time.
  *
- *  Converts psTime to UTC, TAI, UT1, or TT time based on the psTimeType argument.
- *
- *  @return psTime*:    Pointer to psTime.
- */
-psTime* psTimeConvert(
+ *  Converts psTime in-place to UTC, TAI, UT1, or TT time based on the psTimeType argument.
+ *
+ *  @return bool: Successful conversion?
+ */
+bool psTimeConvert(
     psTime *time,                      ///< Time to be converted.
     psTimeType type                    ///< Type to be converted to.
